<?php
/*
 * Vantage Constants
 *
 * @package Vantage
 * @since Vantage 1.0
 */
define( 'VANTAGE_VERSION', '1.1' );
define( 'VANTAGE_TEMPLATE_URI' , get_template_directory_uri() );
define( 'VANTAGE_TEMPLATE_DIR' , get_template_directory() );
define( 'VANTAGE_ACTIVE_MODE' , vn_get_active_mode() );
define( 'VANTAGE_ENV_SUFFIX' , (vn_production_environment() ? '.min' : '') );

define( 'DS_LIVE_COMPOSER_HF', true );
define( 'DS_LIVE_COMPOSER_HF_AUTO', false );

/*
 * Set Content Width
 *
 * @package Vantage
 * @since Vantage 1.0
 */
if ( ! isset( $content_width ) ) {
  $content_width = 1170;
}

if ( ! function_exists( 'vantage_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * @package Vantage
 * @since Vantage 1.0
 */
function vantage_setup() {
  /*
   * Make theme available for translation.
   * Translations can be filed in the /languages/ directory.
   */
  load_theme_textdomain( 'vantage-bb', get_template_directory() . '/languages' );

  // Add default posts and comments RSS feed links to head.
  add_theme_support('automatic-feed-links');
  
  add_theme_support( 'title-tag' );

  // Enable support for Post Thumbnails on posts and pages.
  add_theme_support( 'post-thumbnails' );
  set_post_thumbnail_size( 700, 1400, true );

  // Setup the WordPress core custom background feature.
  add_theme_support( 'custom-background', apply_filters( 'vantage_custom_background_args', array(
    'default-color'      => 'ffffff',
    'default-attachment' => 'fixed',
  ) ) );

  // Register Navs
  register_nav_menus( array(
    'vn-primary' => esc_html__( 'Theme\'s Menu (Non Supermenu)', 'vantage-bb' ),
  ) );

  // WooCommerce Support - Multipurpose Mode only
  if ( vn_get_active_mode() == 'multipurpose' ) {
    add_theme_support( 'woocommerce' );
  }

}
endif; // vantage_setup
add_action( 'after_setup_theme', 'vantage_setup' );

/*
 * Vantage Functions
 *
 * @package Vantage
 * @since Vantage 1.0
 */
function vn_get_active_mode() {
  return get_theme_mod( 'vn_mode', 'multipurpose' );
}
function vn_production_environment() {
  if ( get_theme_mod('vn_production_env', 'no') == 'yes') {
    return true;
  }
}

/*
 * Modify Excerpt Length
 *
 * @package Vantage
 * @since Vantage 1.0
 */
function vantage_excerpt_length( $length ) {
  if (vn_get_active_mode() == 'magazine') {
    return 18;
  }
  else {
    return 30;
  }
}
add_filter( 'excerpt_length', 'vantage_excerpt_length', 999 );


/*
 * Modify Excerpt Length
 *
 * @package Vantage
 * @since Vantage 1.0
 */
function vn_get_thumbnail_url() {
  global $post;
  if ( has_post_thumbnail( $post->ID ) ) {
    $image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'single-post-thumbnail' );
    return esc_url($image[0]);
  }
}

/*
 * The Required Files
 *
 * @package Vantage
 * @since Vantage 1.0
 */
require_once get_template_directory().'/inc/core/enqueue.php';                          // Enqueue Scripts and Stylesheets
require_once get_template_directory().'/inc/core/performance.php';                      // Various Performance Related Methods
require_once get_template_directory().'/inc/core/hooks.php';                            // Hooks to output content
require_once get_template_directory().'/inc/tgm/dependencies.php';                      // TGM: Required Plugins
require_once get_template_directory().'/inc/core/variables.php';                        // Vantage Variables
require_once get_template_directory().'/inc/core/sidebar.php';                          // Sidebar Registrations
require_once get_template_directory().'/inc/core/widgets.php';                          // Widget Registrations
require_once get_template_directory().'/inc/core/template-tags.php';                    // Template Tags
require_once get_template_directory().'/inc/core/vn_bootstrap_navwalker.php';           // Fallback Navwalker
require_once get_template_directory().'/inc/customizer/customizer.php';                 // Customizer
require_once get_template_directory().'/inc/customizer/controls/vn-range-control.php';  // Customizer Control: Range Slider
require_once get_template_directory().'/inc/customizer/controls/vn-color-alpha.php';    // Customizer Control: Alpha Color Picker
require_once get_template_directory().'/inc/customizer/controls/vn-text-editor.php';    // Customizer Control: Textarea
require_once get_template_directory().'/inc/customizer/fonts.php';                      // Customizer Fonts List
require_once get_template_directory().'/inc/customizer/mods.php';                       // Customizer Enqueue Fonts
require_once get_template_directory().'/inc/customizer/callbacks.php';                  // Customizer Callbacks


/*
 * Admin Notices
 *
 * @package Vantage
 * @since Vantage 1.0
 */
function vn_show_import_nag() {
  $vn_user_id = get_current_user_id();
  if ( vn_coreblocks_is_active() && ! get_option('vn_'.vn_get_active_mode().'_required_data') && ! get_user_meta($vn_user_id, 'vn_demo_data_installation_nag') ) { ?>
    
    <div id="message" class="updated error fade">
      <p><b><?php esc_html_e( 'Installation isn\'t complete!', 'vantage-bb' ); ?></b> <?php esc_html_e( 'Vantage needs to import some required data for ', 'vantage-bb' ); ?><?php echo ucfirst(vn_get_active_mode());?> <?php esc_html_e( ' Mode. Please visit the ', 'vantage-bb' ); ?> <a href="<?php echo admin_url() ?>admin.php?page=import"><?php esc_html_e( 'Vantage Importer', 'vantage-bb' ); ?></a></p>
      
      <p>
        <strong><a href="<?php echo admin_url() ?>admin.php?page=import"><?php esc_html_e( 'Vantage Importer', 'vantage-bb' ); ?></a></strong> | 
        <?php echo wp_kses_post( force_balance_tags( ( '<a href="?vn_demo_data_installation_nag=0">Dismiss this notice permanently.</a>' ) ) );?>
      </p>
    </div>
    
   <?php 
  }
}
add_action('admin_notices', 'vn_show_import_nag');

function vn_demo_data_installation_nag() {
  global $current_user;
  $vn_user_id = $current_user->ID;
  /* If user clicks to ignore the notice, add that to their user meta */
  if ( isset($_GET['vn_demo_data_installation_nag']) && '0' == $_GET['vn_demo_data_installation_nag'] ) {
    add_user_meta($vn_user_id, 'vn_demo_data_installation_nag', 'true', true);
  }
}
add_action('admin_init', 'vn_demo_data_installation_nag');

function vn_show_admin_pro_tips() {
  $vn_current_screen = get_current_screen();
  // Widgets Screen Message
  if( $vn_current_screen->id === "widgets" ) { ?>
    <div id="message" class="updated protip fade">
      <p><b><?php esc_html_e( 'Pro Tip: ', 'vantage-bb' ); ?></b><?php esc_html_e( 'Register dynamic sidebars which can be placed on posts and pages using the Page Builder itself. ', 'vantage-bb' ); ?></p>
      <p><strong>
        <a href="<?php echo esc_url( __('http://boldblocks.com/support/sidebars/', 'vantage-bb'));?>" target="_blank"><?php esc_html_e( 'Learn More', 'vantage-bb' ); ?></a></strong>
      </p>
    </div>
    <?php
  }
  
  // Post Templates Screen Message
  if( $vn_current_screen->id === "edit-dslc_templates" ) { ?>
    <div id="message" class="updated protip fade">
      <p><b><?php esc_html_e( 'Pro Tip: ', 'vantage-bb' ); ?></b><?php esc_html_e( 'These are Post Templates, i.e. pre-defined layouts for your posts, built using the Page Builder. You can edit these using the page builder by clicking on View > Activate Editor.', 'vantage-bb' ); ?></p>
      <p><strong>
        <a href="<?php echo esc_url( __('http://boldblocks.com/support/post-templates/', 'vantage-bb'));?>" target="_blank"><?php esc_html_e( 'Learn More', 'vantage-bb' ); ?></a></strong>
      </p>
    </div>
    <?php
  }
  
  // Widgets Screen Message
}
add_action('admin_notices', 'vn_show_admin_pro_tips');

/*
 * Add Classes to Topmenu 
 *
 * @package Vantage
 * @mode Magazine
 * @since Vantage 1.0
 */
if (vn_get_active_mode() == 'magazine') {
  function supermenu_md_topmenu() {
    $sm_md_color_scheme = get_theme_mod('vn_mg_color_scheme', 'supermenumd__nobackground');
    $supermenumd_color  = ($sm_md_color_scheme != 'supermenumd__nobackground' ? 'supermenumd--color' : '');
    $supermenumd_border = (get_theme_mod('vn_mg_border_btm', 'no') == 'no' ? 'supermenumd--noborder' : '');
    echo ' supermenumd '.$supermenumd_color.' '.$sm_md_color_scheme.' '.$supermenumd_border;
  }
  add_action( 'supermenu_topmenu', 'supermenu_md_topmenu');
}

/*
 * Adds button to edit page using Live Composer
 *
 * @package Vantage
 * @since Vantage 1.0
 */
function vn_add_lc_button( $return, $id, $new_title, $new_slug ) {

	// Get post/page with that ID
	$post = get_post( $id );

	// If there's no post with that ID, return the original output
	if ( ! $post ) {
		return $return;
	}

	// If it's not a page return the original output
	if ( $post->post_type != 'page' ) {
		return $return;
	}

	// Getting the permalink if draft or pending
	if( 'draft' == $post->post_status || 'pending' == $post->post_status ) {
		$permalink = set_url_scheme( get_permalink( $post->ID ) );
		$permalink = apply_filters( 'preview_post_link', add_query_arg( 'preview', 'true', $permalink ), $post );
	// Getting the permalink if other statuses ( publish, future... )
	} else {
		$permalink = get_permalink( $id );
	}

	// Define the button HTML
	$button_link = add_query_arg( 'dslc', 'active', $permalink );
	$button_text = 'Activate Editor';
	$button_html = '<span><a href="' . esc_url($button_link) . '" class="vn__pagebuilder_btn" target="_blank">' . esc_attr($button_text) . '</a></span> ';

	// Append new button HTML
	$return .= $button_html;

	// Return altered output
	return wp_kses_post( force_balance_tags( $return ) );

}
if ( defined( 'DS_LIVE_COMPOSER_URL' ) ) {
  add_filter( 'get_sample_permalink_html', 'vn_add_lc_button', 10, 4 ); 
}

/*
 * Add Mode Name and Theme Version to Body Class
 *
 * Mode Name needed for dynamic styling
 * Version needed for support's reference
 *
 * @package Vantage
 * @since Vantage 1.0
 */
function vn_body_class( $classes ) {
  $vn_vantage_bb        = wp_get_theme();
  $vn_vantage_bb_ver	  = $vn_vantage_bb->get( 'Version' );
  $vn_page_transitions  = (get_theme_mod('vn_page_transitions', 'yes') == 'yes' ? 'page-transitions' : '');
  $classes[]            = vn_get_active_mode() . ' ' . $vn_vantage_bb_ver . ' ' . $vn_page_transitions;
  return $classes;
}
add_filter( 'body_class', 'vn_body_class' );

/*
 * Comments Form Tweek
 *
 * @package Vantage
 * @since Vantage 1.0
 */
function vn_update_fields($vn_fields) {
  $vn_commenter = wp_get_current_commenter();
  $vn_req = get_option('require_name_email');
  $vn_aria_req = ($vn_req ? " aria-required='true'" : '');
  $vn_fields['author'] =
    '<p class="comment-form-author">
      <input required minlength="3" maxlength="30" placeholder="' . esc_html__("Your Name*", "vantage-bb") . '" id="author" name="author" type="text" value="' . esc_attr($vn_commenter['comment_author']) .
        '" size="30"' . $vn_aria_req . ' />
      </p>';
  $vn_fields['email'] =
        '<p class="comment-form-email">
        <input required placeholder="' . esc_html__("Your Email*", "vantage-bb") . '" id="email" name="email" type="email" value="' . esc_attr($vn_commenter['comment_author_email']) .
        '" size="30"' . $vn_aria_req . ' />
      </p>';
  $vn_fields['url'] =
        '<p class="comment-form-url">
      <input placeholder="' . esc_html__("URL", "vantage-bb") . '" id="url" name="url" type="url" value="' . esc_attr($vn_commenter['comment_author_url']) .
        '" size="30" />
      </p>';
  return $vn_fields;
}
add_filter('comment_form_default_fields', 'vn_update_fields');

function vn_comment_field($vn_comment_field){
  $vn_comment_field =
    '<p class="comment-form-comment">
      <textarea required placeholder="' . esc_html__("Enter your Comments", "vantage-bb") . '" id="comment" name="comment" cols="45" rows="8" aria-required="true"></textarea>
    </p>';
  return $vn_comment_field;
}
add_filter('comment_form_field_comment', 'vn_comment_field');



/*
 * Custom CSS
 *
 * @package Vantage
 * @since Vantage 1.0
 */
function vn_custom_css() { ?>
  <style id="vantage-custom-css">
    <?php echo wp_filter_nohtml_kses(get_theme_mod('vn_custom_css', '')); ?>
  </style><?php
}
add_action('wp_head', 'vn_custom_css');

/*
 * Back to Top Button
 *
 * @package Vantage
 * @since Vantage 1.0
 */
function vn_backtotop() {
  include ''.get_template_directory().'/inc/core/variables.php';
  if ( is_single() && get_theme_mod('vn_btt_single', 1) ) { ?>
    <a href="#" class="vn__btt vn__btt_single <?php echo esc_attr($vn_btt_style);?>"></a>
  <?php
  }
  if ( is_archive() && get_theme_mod('vn_btt_archive', 1) ) { ?>
    <a href="#" class="vn__btt vn__btt_archive <?php echo esc_attr($vn_btt_style);?>"></a>
  <?php
  }
  if ( is_front_page() && get_theme_mod('vn_btt_home', 1) ) { ?>
    <a href="#" class="vn__btt vn_btt_home <?php echo esc_attr($vn_btt_style);?>"></a>
  <?php
  }
  if ( is_page() && get_theme_mod('vn_btt_page', 0) ) { ?>
    <a href="#" class="vn__btt vn__btt_page <?php echo esc_attr($vn_btt_style);?>"></a>
  <?php
  }
}
add_action('wp_footer', 'vn_backtotop');

/*
 * Page Transitions
 *
 * @package Vantage
 * @since Vantage 1.0
 */
function vn_page_transitions() { 
  if (get_theme_mod('vn_page_transitions', 'yes') == 'yes') {
    echo ' vn__global_wrapper--transition ';
  }
}
add_action('vn_global_wrapper', 'vn_page_transitions');

/*
 * Author Social Links
 *
 * @package Vantage
 * @since Vantage 1.0
 */
function vn_user_social( $vn_contactmethods ) {
  $vn_contactmethods['vn_twitter'] = 'Twitter';
  $vn_contactmethods['vn_facebook'] = 'Facebook';
  $vn_contactmethods['vn_instagram'] = 'Instagram';
  $vn_contactmethods['vn_googleplus'] = 'Google Plus';
  $vn_contactmethods['vn_linkedin'] = 'LinkedIn';
  $vn_contactmethods['vn_youtube'] = 'Youtube';
  $vn_contactmethods['vn_dribbble'] = 'Dribbble';
  $vn_contactmethods['vn_behance'] = 'Behance';
  return $vn_contactmethods;
}
add_filter('user_contactmethods','vn_user_social',10,1);

/*
 * Unregister Unsupported Post Types
 * on the basis of Active Mode.
 *
 * @package Vantage
 * @since Vantage 1.0
 */
//Blog Mode
if ( vn_get_active_mode() === 'blogger' || vn_get_active_mode() === 'magazine' ) {
  //Unregister Post Types
  function vantage_unregister_theme_post_types() {
    global $wp_post_types;
    foreach( array( 'dslc_projects', 'dslc_galleries', 'dslc_staff', 'dslc_downloads', 'dslc_testimonials', 'dslc_partners' ) as $post_type ) {
      if ( isset( $wp_post_types[ $post_type ] ) ) {
        unset( $wp_post_types[ $post_type ] );
      }
    }
  }
  add_action( 'init', 'vantage_unregister_theme_post_types', 20 );

  //Unregister Modules
  function vantage_unregister_modules() {
    foreach( array( 'DSLC_Projects', 'DSLC_Galleries', 'DSLC_Downloads', 'DSLC_Testimonials', 'DSLC_Staff', 'DSLC_Partners', 'DSLC_WooCommerce_Products') as $module_id ) {
      dslc_unregister_module( $module_id );
    }
  }
  add_action( 'dslc_hook_unregister_modules', 'vantage_unregister_modules' );
}
//Photographer Mode
if ( vn_get_active_mode() == 'photographer' ) {
  //Unregister Post Types
  function vantage_unregister_theme_post_types() {
    global $wp_post_types;
    foreach( array( 'dslc_projects', 'dslc_staff', 'dslc_downloads', 'dslc_testimonials', 'dslc_partners' ) as $post_type ) {
      if ( isset( $wp_post_types[ $post_type ] ) ) {
        unset( $wp_post_types[ $post_type ] );
      }
    }
  }
  add_action( 'init', 'vantage_unregister_theme_post_types', 20 );

  //Unregister Modules
  function vantage_unregister_modules() {
    foreach( array( 'DSLC_Projects', 'DSLC_Downloads', 'DSLC_Testimonials', 'DSLC_Staff', 'DSLC_Partners', 'DSLC_WooCommerce_Products') as $module_id ) {
      dslc_unregister_module( $module_id );
    }
  }
  add_action( 'dslc_hook_unregister_modules', 'vantage_unregister_modules' );
}

/*
 * Add a class "excerpt" to all Excerpt
 *
 * @package Vantage
 * @since Vantage 1.0
 */
if( !function_exists( 'vantage_excerpt_class' ) ) {
  function vantage_excerpt_class( $excerpt ) {
    return str_replace('<p', '<p class="vn__excerpt"', $excerpt);
  }
}
add_filter( "the_excerpt", "vantage_excerpt_class" );

/*
 * Count Post Views
 *
 * @package Vantage
 * @since Vantage 1.0
 */
function vn_set_post_views($vn_post_ID) {
  $vn_count_key = 'vantage_post_views_count';
  $vn_count = get_post_meta($vn_post_ID, $vn_count_key, true);
  if($vn_count=='') {
    $vn_count = 0;
    delete_post_meta($vn_post_ID, $vn_count_key);
    add_post_meta($vn_post_ID, $vn_count_key, '0');
  } else {
    $vn_count++;
    update_post_meta($vn_post_ID, $vn_count_key, $vn_count);
  }
}

// Deregister Live Composer's Modules
function vn_unregister_default_modules() {
  dslc_unregister_module( 'DSLC_Image' );
  dslc_unregister_module( 'DSLC_Navigation' );
  dslc_unregister_module( 'DSLC_Separator' );
}
add_action( 'dslc_hook_unregister_modules', 'vn_unregister_default_modules' );