<?php
/**
 * Enqueue Styles & Scripts
 *
 * @package Vantage
 * @since Vantage 1.0
 */

/* Table of Content
 *	1. Global CSS Files
 *		1.1 Preloader
 *		1.2 bbPress
 *		1.3 Mode Specific CSS
 *		1.4 Fontawesome
 *    1.5 Material
 *		1.6 Theme Stylesheet
 *    1.7 Builder Mains
 *
 *	2. Global JS Files
 *		2.1 smoothscroll.js
 *		2.2 skrollr.js
 *		2.3 swiper-v2.js
 *		2.4 material.js
 *		2.5 comment-reply
 *    2.6 theiaStickySidebar.js
 *		2.7 scripts.js
 *
 *	5. Admin Styles
 */

function vn_scripts() {
  //Load the Variables

  // 1. Global CSS Files
    // 1.1 Preloader
    if ( get_theme_mod('vn_progress_bar', 'yes') == 'yes' || get_theme_mod('vn_page_transitions', 'yes') == 'yes') {
      wp_register_script( 'vn-preloader-js', get_template_directory_uri() .'/assets/js/vn.preloader'.VANTAGE_ENV_SUFFIX.'.js', array( 'jquery' ), VANTAGE_VERSION, false );
      wp_enqueue_script( 'vn-preloader-js' );
    }

    // 1.2 bbpress.css
    if ( class_exists('bbPress') && is_bbpress() ) {
      wp_dequeue_style('bbp-default');
      wp_enqueue_style('vn-bbpress', get_template_directory_uri() . '/assets/css/vn.bbpress'.VANTAGE_ENV_SUFFIX.'.css');
    }

    // 1.3 Mode Specific CSS
    wp_enqueue_style('vn-modecss', get_template_directory_uri() . '/mode/'.vn_get_active_mode().'/style'.VANTAGE_ENV_SUFFIX.'.css');

    // 1.4 Fontawesome
    wp_enqueue_style( 'vn-fontawesome', get_template_directory_uri() . '/assets/css/vn.fontawesome.min.css');
    
    // 1.5 Material
    if ( vn_get_active_mode() == 'magazine' ) {
      wp_enqueue_style( 'vn-material', get_template_directory_uri() . '/assets/css/vn.material'.VANTAGE_ENV_SUFFIX.'.css');
    }

    // 1.6 style.css
    wp_enqueue_style('vantage', get_stylesheet_uri());
    
    // 1.7 Material
    wp_dequeue_style( 'dslc-builder-main-css' );
    global $dslc_active;
    if ( $dslc_active && is_user_logged_in() && current_user_can( DS_LIVE_COMPOSER_CAPABILITY ) ) {
    wp_enqueue_style( 'vn-builder-main', get_template_directory_uri() . '/assets/css/vn.builder-main-2.css');
    }

  // 2.0 Global JS Files
    // 2.1 smoothscroll.js
    wp_register_script( 'vn-smoothscroll-js', get_template_directory_uri() .'/assets/js/vn.smoothscroll'.VANTAGE_ENV_SUFFIX.'.js', array( 'jquery' ), VANTAGE_VERSION, true );
    if ( get_theme_mod( 'vn_smoothscroll', 'disabled' ) == 'enabled' && vn_get_active_mode() !== 'photographer') {
      wp_enqueue_script( 'vn-smoothscroll-js' );
    }
    
    // 2.2 material.js
    if ( vn_get_active_mode() == 'magazine' ) {
      wp_register_script( 'vn-material-js', get_template_directory_uri() .'/assets/js/vn.material'.VANTAGE_ENV_SUFFIX.'.js', array( 'jquery' ), VANTAGE_VERSION, false );
      wp_enqueue_script( 'vn-material-js' );
    }

    // 2.3 swiper-v2.js
    wp_register_script( 'vn-swiper-v2-js', get_template_directory_uri() .'/assets/js/vn.swiper-v2.min.js', array( 'jquery' ), VANTAGE_VERSION, false );
    wp_enqueue_script( 'vn-swiper-v2-js' );
    
    // 2.4 comment-reply
    if ( is_singular() ) wp_enqueue_script( "comment-reply" );
    
    // 2.5 theiaStickySidebar.js
      wp_register_script( 'vn-sticky-sidebar-js', get_template_directory_uri() .'/assets/js/vn.sticky-sidebar'.VANTAGE_ENV_SUFFIX.'.js', array( 'jquery' ), VANTAGE_VERSION, false );
      wp_enqueue_script( 'vn-sticky-sidebar-js' );
    

    // 2.7 scripts.js
    wp_register_script( 'vn-scripts-js', get_template_directory_uri() .'/assets/js/vn.scripts'.VANTAGE_ENV_SUFFIX.'.js', array( 'jquery' ), VANTAGE_VERSION, false );
    wp_localize_script( 'vn-scripts-js', 'vn_vars', array(
      'url'                       => admin_url( 'admin-ajax.php' ),
      'nonce'                     => wp_create_nonce( 'ajax-nonce' ),
      'vn_active_mode'					  => esc_attr(vn_get_active_mode()),
      'vn_progress_bar'           => get_theme_mod('vn_progress_bar', 'yes'),
      'vn_page_transitions'       => get_theme_mod('vn_page_transitions', 'yes'),
      'vn_pg_trns_show_logo'      => get_theme_mod('vn_pg_trns_show_logo', 'yes'),
      'vn_pg_trns_logo'           => get_theme_mod('vn_pg_trns_logo', VANTAGE_TEMPLATE_URI.'/assets/img/logo/vantage-icon-black.png'),
      'vn_ph_cursor_follower'     => get_theme_mod('vn_ph_cursor_follower', 'yes'),
      'vn_btt_visibility'         => get_theme_mod('vn_btt_visibility', 800),
      'vn_ph_mouse_animation'     => get_theme_mod('vn_ph_mouse_animation', 'yes'),
      'vn_ph_cursor_follower'     => get_theme_mod('vn_ph_cursor_follower', 'yes'),
      
    ) );
    wp_enqueue_script( 'vn-scripts-js' );
}
add_action('wp_enqueue_scripts', 'vn_scripts'); //Devnote: if adding 0 here, keep in mind, bbpress.css will load after bbpress.css in plugin.

  // 5.0 Admin Styles
  function vantage_admin_style() {
    wp_enqueue_style( 'vn-dashboard-style', get_template_directory_uri() . '/assets/css/vn.dashboard-style.css');
    wp_register_script( 'vn-swiper-v3-js', get_template_directory_uri() .'/assets/js/vn.swiper-v3.min.js', array( 'jquery' ), VANTAGE_VERSION, true );
    wp_enqueue_script( 'vn-swiper-v3-js' );
    wp_enqueue_style( 'vn-swiper-v3', get_template_directory_uri() . "/assets/css/vn.swiper-v3.min.css");
    
  }
  add_action( 'admin_enqueue_scripts', 'vantage_admin_style' );