<?php
/*
 * Vantage Template Tags used throughout the theme
 *
 * @package Vantage
 * @since Vantage 1.0
 */
if ( ! function_exists( 'vn_content_nav' ) ) :
/**
 * Display navigation to next/previous pages when applicable
 */
function vn_content_nav( $nav_id ) {
	global $wp_query, $post;

	// Don't print empty markup on single pages if there's nowhere to navigate.
	if ( is_single() ) {
		$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
		$next = get_adjacent_post( false, '', false );

		if ( ! $next && ! $previous )
			return;
	}

	// Don't print empty markup in archives if there's only one page.
	if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) )
		return;

	$nav_class = ( is_single() ) ? 'post-navigation' : 'paging-navigation';

	?>
	<nav role="navigation" id="<?php echo esc_attr( $nav_id ); ?>" class="<?php echo esc_attr($nav_class); ?>">

	<?php if ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : ?>

		<?php if ( get_next_posts_link() ) : ?>
		<div class="nav-previous"><?php next_posts_link( esc_html__( 'Older posts', 'vantage-bb' ) ); ?></div>
		<?php endif; ?>

		<?php if ( get_previous_posts_link() ) : ?>
		<div class="nav-next"><?php previous_posts_link( esc_html__( 'Newer posts', 'vantage-bb' ) ); ?></div>
		<?php endif; ?>

	<?php endif; ?>

	</nav><!-- #<?php echo esc_html( $nav_id ); ?> -->
	<?php
}
endif; // vn_content_nav

if ( ! function_exists( 'vn_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 */
function vn_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;

	if ( 'pingback' == $comment->comment_type || 'trackback' == $comment->comment_type ) : ?>

	<li id="comment-<?php comment_ID(); ?>" <?php comment_class(); ?>>
		<div class="comment-body">
			<?php esc_html_e( 'Pingback:', 'vantage-bb' ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( esc_html__( 'Edit', 'vantage-bb' ), '<span class="edit-link">', '</span>' ); ?>
		</div>

	<?php else : ?>

	<li id="comment-<?php comment_ID(); ?>" <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ); ?>>
		<article id="div-comment-<?php comment_ID(); ?>" class="comment-body">
			<footer class="comment-meta row">
				<div class="comment-author vcard col-md-6 col-sm-6 col-xs-6">
					<?php if ( 0 != $args['avatar_size'] ) echo get_avatar( $comment, $args['avatar_size'] ); ?>
					<?php printf( wp_kses_post( force_balance_tags ( '%s <span class="says">says:</span>', 'vantage-bb' ) ), sprintf( '<cite class="fn">%s</cite>', get_comment_author_link() ) ); ?>
				</div><!-- .comment-author -->

				<div class="comment-metadata col-md-6 col-sm-6 col-xs-6">
					<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
						<time datetime="<?php comment_time( 'c' ); ?>">
							<?php printf( _x( '%1$s at %2$s', '1: date, 2: time', 'vantage-bb' ), get_comment_date(), get_comment_time() ); ?>
						</time>
					</a>
					<?php edit_comment_link( esc_html__( 'Edit', 'vantage-bb' ), '<span class="edit-link">', '</span>' ); ?>
				</div><!-- .comment-metadata -->

				<?php if ( '0' == $comment->comment_approved ) : ?>
				<p class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.', 'vantage-bb' ); ?></p>
				<?php endif; ?>
			</footer><!-- .comment-meta -->

			<div class="comment-content row">
				<div class="col-md-12">
				<?php comment_text(); ?>
				</div>
			</div><!-- .comment-content -->

			<?php
				comment_reply_link( array_merge( $args, array(
					'add_below' => 'div-comment',
					'depth'     => $depth,
					'max_depth' => $args['max_depth'],
					'before'    => '<div class="reply">',
					'after'     => '</div>',
				) ) );
			?>
		</article><!-- .comment-body -->

	<?php
	endif;
}
endif; // ends check for vn_comment()

if ( ! function_exists( 'vn_get_the_thumb_uri' ) ) :
/**
 * Prints the attached image with a link to the next attached image.
 */
function vn_get_the_thumb_uri() {
  global $post;
  if (has_post_thumbnail( $post->ID ) ) {
		$image = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'single-post-thumbnail' );
		echo esc_url($image[0]);
	}
}
endif;


if ( ! function_exists( 'vn_the_attached_image' ) ) :
/**
 * Prints the attached image with a link to the next attached image.
 */
function vn_the_attached_image() {
	$post                = get_post();
	$attachment_size     = apply_filters( 'vantage_attachment_size', array( 1200, 1200 ) );
	$next_attachment_url = wp_get_attachment_url();

	/**
	 * Grab the IDs of all the image attachments in a gallery so we can get the
	 * URL of the next adjacent image in a gallery, or the first image (if
	 * we're looking at the last image in a gallery), or, in a gallery of one,
	 * just the link to that image file.
	 */
	$attachment_ids = get_posts( array(
		'post_parent'    => $post->post_parent,
		'fields'         => 'ids',
		'numberposts'    => -1,
		'post_status'    => 'inherit',
		'post_type'      => 'attachment',
		'post_mime_type' => 'image',
		'order'          => 'ASC',
		'orderby'        => 'menu_order ID'
	) );

	// If there is more than 1 attachment in a gallery...
	if ( count( $attachment_ids ) > 1 ) {
		foreach ( $attachment_ids as $attachment_id ) {
			if ( $attachment_id == $post->ID ) {
				$next_id = current( $attachment_ids );
				break;
			}
		}

		// get the URL of the next image attachment...
		if ( $next_id )
			$next_attachment_url = get_attachment_link( $next_id );

		// or get the URL of the first image attachment.
		else
			$next_attachment_url = get_attachment_link( array_shift( $attachment_ids ) );
	}

	printf( '<a href="%1$s" title="%2$s" rel="attachment">%3$s</a>',
		esc_url( $next_attachment_url ),
		the_title_attribute( array( 'echo' => false ) ),
		wp_get_attachment_image( $post->ID, $attachment_size )
	);
}
endif;

/**
* Print post meta HTML
*
* @param    string         $post_id        ID of the post to use
* @param    array           $display        Configuration arguments. (date, author, categories, tags)
* @param    string         $wrapper        Type of html wrapper
* @param    string         $wrapper_class  Class of HTML wrapper
* @echo     string                          Post Meta HTML
*/
if( !function_exists( 'vn_post_meta' ) ) {
    function vn_post_meta( $post_id = NULL , $display = NULL, $wrapper = 'div', $wrapper_class = 'vn__meta' ) {
        // If there is no post ID specified, use the current post, does not affect post author, yet.
        if( NULL == $post_id ) {
            global $post;
            $post_id = $post->ID;
        }

        // If there are no items to display, return nothing
        if( !is_array( $display ) ) $display = array( 'date', 'author', 'categories', 'tags' );

        foreach ( $display as $meta ) {
            switch ( $meta ) {
                case 'date' :
                    $meta_to_display[] = '<span class="meta-item meta-date"><i class="fa fa-clock-o"></i> ' . get_the_time(  get_option( 'date_format' ) , $post_id ) . '</span>';
                    break;
                case 'author' :
                    $meta_to_display[] = '<span class="meta-item meta-author"><i class="fa fa-user"></i> ' . vn_get_the_author( $post_id ) . '</span>';
                    break;
                case 'categories' :
                    $categories = '';

                    // Use different terms for different post types
                    if( 'post' == get_post_type( $post_id ) ){
                        $the_categories = get_the_category( $post_id );
                    } elseif( 'portfolio' == get_post_type( $post_id ) ) {
                        $the_categories = get_the_terms( $post_id , 'portfolio-category' );
                    } else {
                        $the_categories = FALSE;
                    }

                    // If there are no categories, skip to the next case
                    if( !$the_categories ) continue;

                    foreach ( $the_categories as $category ){
                        $categories[] = ' <a href="'.get_category_link( $category->term_id ).'" title="' . esc_attr( sprintf( wp_kses_post( force_balance_tags ( "View all posts in %s", 'vantage-bb' ) ), $category->name ) ) . '">'.$category->name.'</a>';
                    }
                    $meta_to_display[] = '<span class="meta-item meta-category"><i class="fa fa-folder-open-o"></i> ' . implode( __( ', ' , 'vantage-bb' ), $categories ) . '</span>';
                    break;
                case 'tags' :
                    $tags = '';

                    if( 'post' == get_post_type( $post_id ) ){
                        $the_tags = get_the_tags( $post_id );
                    } else {
                        $the_tags = FALSE;
                    }

                    // If there are no tags, skip to the next case
                    if( !$the_tags ) continue;

                    foreach ( $the_tags as $tag ){
                        $tags[] = ' <a href="'.get_tag_link( $tag->term_id ).'" title="' . esc_attr( sprintf( wp_kses_post( force_balance_tags ( "View all posts tagged %s", 'vantage-bb' ) ), $tag->name ) ) . '">'.$tag->name.'</a>';
                    }
                    $meta_to_display[] = '<span class="meta-item meta-tags"><i class="fa fa-tags"></i> ' . implode( __( ', ' , 'vantage-bb' ), $tags ) . '</span>';
                    break;
                break;
            } // switch meta
        } // foreach $display

        if( !empty( $meta_to_display ) ) {
            echo '<' . $wrapper . ( ( '' != $wrapper_class ) ? ' class="' . $wrapper_class .'"' : NULL ) . '>';
							echo implode( ' ' , $meta_to_display );
            echo '</' . $wrapper . '>';
        }
    }
}

/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
if ( ! function_exists( 'vn_get_the_author' ) ) {
    function vn_get_the_author() {
        return sprintf( wp_kses_post( force_balance_tags ( '<a href="%1$s" title="%2$s" rel="author">%3$s</a>' , 'vantage-bb' ) ),
            esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
            esc_attr( sprintf( wp_kses_post( force_balance_tags ( 'View all posts by %s', 'vantage-bb' ) ), get_the_author() ) ),
            esc_attr( get_the_author() )
        );
    }
}

/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
if ( ! function_exists( 'vn_link_pages' ) ) {
    function vn_link_pages() {
        wp_link_pages( array(
              'before'      => '<div class="vn__internal_pagination"><span class="vn__internal_pagination_title">' . __( 'Pages:', 'vantage-bb' ) . '</span>',
              'after'       => '</div>',
              'link_before' => '<span class="vn__internal_pagination_number">',
              'link_after'  => '</span>',
              'pagelink'    => '<span class="sr-only">' . __( 'Page', 'vantage-bb' ) . ' </span>%',
              'separator'   => '<span class="sr-only">, </span>',
          ) );
    }
}

/**
* Print pagination
*
* @param    array           $args           Arguments for this function, including 'query', 'range'
* @param    string         $wrapper        Type of html wrapper
* @param    string         $wrapper_class  Class of HTML wrapper
* @echo     string                          Post Meta HTML
*/
if( !function_exists( 'vn_pagination' ) ) {
	function vn_pagination( $args = NULL , $wrapper = 'div', $wrapper_class = 'vn__pagination' ) {

		// Set up some globals
		global $wp_query, $paged;

		// Get the current page
		if( empty($paged ) ) $paged = ( get_query_var('page') ? get_query_var('page') : 1 );

		// Set a large number for the 'base' argument
		$big = 99999;

		// Get the correct post query
		if( !isset( $args[ 'query' ] ) ){
			$use_query = $wp_query;
		} else {
			$use_query = $args[ 'query' ];
		} ?>

		<<?php echo esc_attr($wrapper); ?> class="<?php echo esc_attr($wrapper_class); ?>">
			<?php echo paginate_links( array(
				'base' => str_replace( $big, '%#%', get_pagenum_link($big) ),
				'prev_next' => true,
				'mid_size' => ( isset( $args[ 'range' ] ) ? $args[ 'range' ] : 3 ) ,
				'prev_text' => '<',
				'next_text' => '>',
				'type' => 'plain',
				'current' => $paged,
				'total' => $use_query->max_num_pages
			) ); ?>
		</<?php echo esc_attr($wrapper); ?>>
	<?php }
}