<?php
/*
 * Popular Posts Widget
 * 
 * @package Vantage
 * @since Vantage 1.0 
 */
class VN_Popular_Posts extends WP_Widget {
        
    function __construct() {
        $widget_ops = array('classname' => 'widget_popular_posts', 'description' => esc_html__( "The most Popular Posts site", 'vantage-bb') );
        parent::__construct('popular-posts', esc_html__('Popular Posts [Vantage]', 'vantage-bb'), $widget_ops);
        $this->alt_option_name = 'widget_popular_posts';

        add_action( 'save_post', array($this, 'flush_widget_cache') );
        add_action( 'deleted_post', array($this, 'flush_widget_cache') );
        add_action( 'switch_theme', array($this, 'flush_widget_cache') );
    }

    function widget($args, $instance) {
        $cache = wp_cache_get('widget_popular_posts', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo $cache[ $args['widget_id'] ];
            return;
        }

        ob_start();
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : '';
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 10;
        if ( ! $number )
            $number = 5;
        $vn_show_hover_effect = isset( $instance['vn_show_hover_effect'] ) ? $instance['vn_show_hover_effect'] : false;
        $vn_thumbnail_width = isset( $instance['vn_thumbnail_width'] ) ? absint( $instance['vn_thumbnail_width'] ) : 20;
?>
        <?php echo $before_widget; ?>
        <?php if ( $title ) echo $before_title . $title . $after_title; ?>
        <ul>
          <?php $vn_popularpost = new WP_Query( array( 'posts_per_page' => $number, 'ignore_sticky_posts' => 1, 'meta_key' => 'vantage_post_views_count', 'orderby' => 'meta_value_num', 'order' => 'DESC'  ) );
          while ( $vn_popularpost->have_posts() ) : $vn_popularpost->the_post();
          global $post;?>
            <li>
              <a href="<?php echo the_permalink();?>" target="_blank" <?php post_class('vn__popularposts_row'); ?>>
                <div class="vn__popularposts_thumb" style="max-width:<?php echo esc_attr($vn_thumbnail_width);?>%;">
                  <div class="vn__popularposts_thumb_inner">
                  <?php echo get_the_post_thumbnail( $post->ID, '100by100' );?>
                  </div>
                  <div class="vn__post_stats">
                    <span title="Likes" class="vn__post_stats_likes"><i class="fa fa-heart"></i> <?php echo get_post_meta( $post->ID, "_post_like_count", true ); ?></span>
                    <span title="Views" class="vn__post_stats_views"><i class="fa fa-eye"></i> <?php echo get_post_meta($post->ID, 'vantage_post_views_count', true);?></span>
                  </div>
                </div>
                <div class="vn__popularposts_title" style="max-width:<?php echo esc_attr( 100 - $vn_thumbnail_width);?>%;">
                  <?php echo the_title();?>
                  <div class="vn__popularposts_author">
                    <?php echo esc_html__('By', 'vantage-bb');?>  <?php echo get_the_author_link(); ?>
                  </div>
                </div>
              </a>
            </li> 
          <?php endwhile; ?>
        </ul>
        
        <?php echo $after_widget; ?>
<?php
        // Reset the global $the_post as this query will have stomped on it
        wp_reset_postdata();


        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('widget_popular_posts', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['number'] = (int) $new_instance['number'];
        $instance['vn_show_hover_effect'] = (bool) $new_instance['vn_show_hover_effect'];
        $instance['vn_thumbnail_width'] = (int) $new_instance['vn_thumbnail_width'];
        $this->flush_widget_cache();

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_popular_posts']) )
            delete_option('widget_popular_posts');

        return $instance;
    }

    function flush_widget_cache() {
        wp_cache_delete('widget_popular_posts', 'widget');
    }

    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
        $number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
        $vn_show_hover_effect = isset( $instance['vn_show_hover_effect'] ) ? (bool) $instance['vn_show_hover_effect'] : false;
        $vn_thumbnail_width = isset( $instance['vn_thumbnail_width'] ) ? absint( $instance['vn_thumbnail_width'] ) : 20;
?>
        <p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'vantage-bb' ); ?></label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

        <p><label for="<?php echo esc_attr($this->get_field_id( 'number' )); ?>"><?php esc_html_e( 'Number of posts to show:', 'vantage-bb' ); ?></label>
        <input id="<?php echo esc_attr($this->get_field_id( 'number' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo esc_attr($number); ?>" size="3" /></p>

        <p><input class="checkbox" type="checkbox" <?php checked( $vn_show_hover_effect ); ?> id="<?php echo esc_attr($this->get_field_id( 'vn_show_hover_effect' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'vn_show_hover_effect' )); ?>" />
        <label for="<?php echo esc_attr($this->get_field_id( 'vn_show_hover_effect' )); ?>"><?php esc_html_e( 'Display Hover Effect?', 'vantage-bb' ); ?></label></p>
        
        <p>
        <p>
          <label for="<?php echo esc_attr($this->get_field_id( 'vn_thumbnail_width' )); ?>"><?php esc_html_e( 'Thumbnail Width (%):', 'vantage-bb' ); ?></label>
          <input id="<?php echo esc_attr($this->get_field_id( 'vn_thumbnail_width' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'vn_thumbnail_width' )); ?>" type="text" value="<?php echo esc_attr($vn_thumbnail_width); ?>" size="3" />
        </p>
<?php
    }
}

/*
 * About Author Widget
 * 
 * @package Vantage
 * @since Vantage 1.0 
 */
class VN_About_Author_Widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	public function __construct() {
		parent::__construct(
			'vn_about_author_widget', // Base ID
			'About Author [Vantage]', // Name
			array( 'description' => 'About author widget.' ) // Args
		);
	}

	public function widget( $args, $instance ) {
		
		extract( $args );
		$title = apply_filters( 'widget_title', $instance['title'] );
		
		$vn_author_image = $instance['vn_author_image'];
		$vn_author_name = $instance['vn_author_name'];
		$vn_position = $instance['vn_position'];
		$vn_text = $instance['vn_text'];
		$vn_button_url = $instance['vn_button_url'];
		$vn_button_text = $instance['vn_button_text'];

		echo wp_kses_post( ( $before_widget ) );

		if ( ! empty( $title ) )
			echo wp_kses_post( ( $before_title . $title . $after_title ) );

		?>

			<div class="vn-about-author-widget <?php if ( $vn_author_image == '' ) echo 'vn-about-author-widget-no-avatar'; ?>">

				<?php if ( $vn_author_image !== '' ) : ?>
					<div class="vn-about-author-widget-avatar"><img src="<?php echo esc_url( $vn_author_image ); ?>" /></div>
					<div class="vn-about-author-widget-avatar-overlay"></div>
				<?php endif; ?>
				<div class="vn-about-author-widget-info">
					<h2 class="vn-about-author-widget-name"><?php echo esc_html( $name ); ?></h2>
					<p class="vn-about-author-widget-position"><?php echo esc_html( $vn_position ); ?></p>
					<div class="vn-about-author-widget-text"><?php echo esc_html( $vn_text ); ?></div>
					<?php if ( isset( $vn_button_url ) && strlen( $vn_button_url ) > 0 ) : ?>
          <a href="<?php echo esc_attr( $vn_button_url ); ?>" class="vn__btn"><?php echo esc_html( $vn_button_text ); ?></a>
					<?php endif; ?>
				</div><!-- .vn-about-author-widget-info -->

			</div><!-- .vn-about-author-widget -->

		<?php

		echo wp_kses_post( ( $after_widget ) );

	}

	public function update( $new_instance, $old_instance ) {
		
		$instance = array();
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['vn_author_image'] = strip_tags( $new_instance['vn_author_image'] );
		$instance['vn_author_name'] = strip_tags( $new_instance['vn_author_name'] );
		$instance['vn_position'] = strip_tags( $new_instance['vn_position'] );
		$instance['vn_text'] = strip_tags( $new_instance['vn_text'] );
		$instance['vn_button_url'] = strip_tags( $new_instance['vn_button_url'] );
		$instance['vn_button_text'] = strip_tags( $new_instance['vn_button_text'] );

		return $instance;

	}

	public function form( $instance ) {

		if ( isset( $instance[ 'title' ] ) ) $title = $instance[ 'title' ]; else $title = 'About Me';
		if ( isset( $instance[ 'vn_author_image' ] ) ) $vn_author_image = $instance[ 'vn_author_image' ]; else $vn_author_image = '';
		if ( isset( $instance[ 'vn_author_name' ] ) ) $vn_author_name = $instance[ 'vn_author_name' ]; else $vn_author_name = 'Hi! My name is Elizabeth.';
		if ( isset( $instance[ 'vn_position' ] ) ) $vn_position = $instance[ 'vn_position' ]; else $vn_position = 'Fashion Designer';
		if ( isset( $instance[ 'vn_text' ] ) ) $vn_text = $instance[ 'vn_text' ]; else $vn_text = 'Etiam porta elit mi, quis viverra dui aliquet ultricies. Nulla non tortor ac.';
		if ( isset( $instance[ 'vn_button_url' ] ) ) $vn_button_url = $instance[ 'vn_button_url' ]; else $vn_button_url = '';
		if ( isset( $instance[ 'vn_button_text' ] ) ) $vn_button_text = $instance[ 'vn_button_text' ]; else $vn_button_text = 'LEARN MORE';

		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'vantage-bb' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'vn_author_image' ) ); ?>"><?php esc_html_e( 'Author Image URL:', 'vantage-bb' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'vn_author_image' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'vn_author_image' ) ); ?>" type="text" value="<?php echo esc_attr( $vn_author_image ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'vn_author_name' ) ); ?>"><?php esc_html_e( 'Heading Title:', 'vantage-bb' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'vn_author_name' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'vn_author_name' ) ); ?>" type="text" value="<?php echo esc_attr( $vn_author_name ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'vn_position' ) ); ?>"><?php esc_html_e( 'Heading Subtitle:', 'vantage-bb' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'vn_position' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'vn_position' ) ); ?>" type="text" value="<?php echo esc_attr( $vn_position ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'vn_text' ) ); ?>"><?php esc_html_e( 'Author Description:', 'vantage-bb' ); ?></label> 
			<textarea class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'vn_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'vn_text' ) ); ?>"><?php echo esc_html( $vn_text ); ?></textarea>
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'vn_button_url' ) ); ?>"><?php esc_html_e( 'Button URL:', 'vantage-bb' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'vn_button_url' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'vn_button_url' ) ); ?>" type="text" value="<?php echo esc_attr( $vn_button_url ); ?>" />
		</p>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'vn_button_text' ) ); ?>"><?php esc_html_e( 'Button Text:', 'vantage-bb' ); ?></label> 
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'vn_button_text' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'vn_button_text' ) ); ?>" type="text" value="<?php echo esc_attr( $vn_button_text ); ?>" />
		</p>

		<?php 

	}

}

/*
 * Recent Testimonials Widget
 * 
 * @package Vantage
 * @since Vantage 1.0 
 */
class VN_Widget_Recent_Testimonials extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_recent_testimonials', 'description' => esc_html__( "The most recent testimonials on your site", 'vantage-bb') );
        parent::__construct('recent-testimonials', esc_html__('Recent Testimonials [Vantage]', 'vantage-bb'), $widget_ops);
        $this->alt_option_name = 'widget_recent_testimonials';

        add_action( 'save_post', array($this, 'flush_widget_cache') );
        add_action( 'deleted_post', array($this, 'flush_widget_cache') );
        add_action( 'switch_theme', array($this, 'flush_widget_cache') );
    }

    function widget($args, $instance) {
        $cache = wp_cache_get('widget_recent_testimonials', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo esc_attr($cache[ $args['widget_id'] ]);
            return;
        }

        ob_start();
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : '';
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 10;
        if ( ! $number )
            $number = 10;
        $vn_show_testi_author = isset( $instance['vn_show_testi_author'] ) ? $instance['vn_show_testi_author'] : false;

        $r = new WP_Query( apply_filters( 'widget_posts_args', array( 'post_type' => 'dslc_testimonials','posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true ) ) );
        if ($r->have_posts()) :
?>
        <?php echo wp_kses_post( ( $before_widget ) ); ?>
        <?php if ( $title ) echo wp_kses_post( ( $before_title . $title . $after_title ) ); ?>
        <script>
        	jQuery(document).ready(function($) {
					  $("#vn-testimonial-carousel").owlCarousel({
					      slideSpeed : 300,
					      autoHeight: true,
					      autoPlay: true,
					      baseClass: "vn-owl-carousel",
					      paginationSpeed : 400,
					      nav: true,
					      loop: true,
					      items: 1
					  });		 
					});
        </script>
        <div id="vn-testimonial-carousel" class="vn-owl-carousel vn-testimonial-widget">
        <?php while ( $r->have_posts() ) : $r->the_post(); ?>
            <div>
                <?php echo get_the_content();?>
                <br><br>
								<?php if ( $vn_show_testi_author ) : ?>
								<span class="test-author">
									<?php echo get_avatar( get_the_author_meta( 'ID' ), 50 ); ?>
									<ul class="cd-author-info">
										<li><?php echo get_the_title(); ?></li>
										<li><?php echo get_post_meta( get_the_ID(), 'dslc_testimonial_author_pos', true );?></li>
									</ul>
								</span>
								<?php endif; ?>
            </div>
            
        <?php endwhile; ?>
        </div>
        <?php echo wp_kses_post( ( $after_widget ) ); ?>
<?php
        // Reset the global $the_post as this query will have stomped on it
        wp_reset_postdata();

        endif;

        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('widget_recent_testimonials', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['number'] = (int) $new_instance['number'];
        $instance['vn_show_testi_author'] = (bool) $new_instance['vn_show_testi_author'];
        $this->flush_widget_cache();

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_recent_entries_extended']) )
            delete_option('widget_recent_entries_extended');

        return $instance;
    }

    function flush_widget_cache() {
        wp_cache_delete('widget_recent_testimonials', 'widget');
    }

    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? $instance['title'] : '';
        $number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
        $vn_show_testi_author = isset( $instance['vn_show_testi_author'] ) ? (bool) $instance['vn_show_testi_author'] : false;
?>
        <p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'vantage-bb' ); ?></label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

        <p><label for="<?php echo esc_attr($this->get_field_id( 'number' )); ?>"><?php esc_html_e( 'Number of posts to show:', 'vantage-bb' ); ?></label>
        <input id="<?php echo esc_attr($this->get_field_id( 'number' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo esc_attr($number); ?>" size="3" /></p>

        <p><input class="checkbox" type="checkbox" <?php checked( $vn_show_testi_author ); ?> id="<?php echo esc_attr($this->get_field_id( 'vn_show_testi_author' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'vn_show_testi_author' )); ?>" />
        <label for="<?php echo esc_attr($this->get_field_id( 'vn_show_testi_author' )); ?>"><?php esc_html_e( 'Show Testimonial Author?', 'vantage-bb' ); ?></label></p>
<?php
    }
}

/*
 * Recent Posts Widget
 * 
 * @package Vantage
 * @since Vantage 1.0 
 */
class VN_MG_Widget_Recent_Posts extends WP_Widget {

    function __construct() {
        $widget_ops = array('classname' => 'widget_recent_entries', 'description' => esc_html__( "The most recent posts on your site", 'vantage-bb') );
        parent::__construct('recent-posts', esc_html__('Recent Posts [Vantage]', 'vantage-bb'), $widget_ops);
        $this->alt_option_name = 'widget_recent_entries';

        add_action( 'save_post', array($this, 'flush_widget_cache') );
        add_action( 'deleted_post', array($this, 'flush_widget_cache') );
        add_action( 'switch_theme', array($this, 'flush_widget_cache') );
    }

    function widget($args, $instance) {
        $cache = wp_cache_get('widget_recent_posts', 'widget');

        if ( !is_array($cache) )
            $cache = array();

        if ( ! isset( $args['widget_id'] ) )
            $args['widget_id'] = $this->id;

        if ( isset( $cache[ $args['widget_id'] ] ) ) {
            echo esc_attr($cache[ $args['widget_id'] ]);
            return;
        }

        ob_start();
        extract($args);

        $title = ( ! empty( $instance['title'] ) ) ? $instance['title'] : esc_html__( 'Recent Posts', 'vantage-bb' );
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );
        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 10;
        if ( ! $number )
            $number = 10;
        $show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

        $r = new WP_Query( apply_filters( 'widget_posts_args', array( 'posts_per_page' => $number, 'no_found_rows' => true, 'post_status' => 'publish', 'ignore_sticky_posts' => true ) ) );
        if ($r->have_posts()) :
?>
        <?php echo wp_kses_post( ( $before_widget ) ); ?>
        <?php if ( $title ) echo wp_kses_post( ( $before_title . $title . $after_title ) ); ?>
        <ul>
        <?php while ( $r->have_posts() ) : $r->the_post(); ?>
            <li>
              <a href="<?php the_permalink() ?>" title="<?php echo esc_attr( get_the_title() ? get_the_title() : get_the_ID() ); ?>"><?php echo get_the_post_thumbnail('thumbnail');?>
              <span class="post-title"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></span>
              </a>
            <?php if ( $show_date ) : ?>
                <span class="post-date"><?php echo get_the_date(); ?></span>
            <?php endif; ?>
            </li>
        <?php endwhile; ?>
        </ul>
        <?php echo wp_kses_post( ( $after_widget ) ); ?>
<?php
        // Reset the global $the_post as this query will have stomped on it
        wp_reset_postdata();

        endif;

        $cache[$args['widget_id']] = ob_get_flush();
        wp_cache_set('widget_recent_posts', $cache, 'widget');
    }

    function update( $new_instance, $old_instance ) {
        $instance = $old_instance;
        $instance['title'] = strip_tags($new_instance['title']);
        $instance['number'] = (int) $new_instance['number'];
        $instance['show_date'] = (bool) $new_instance['show_date'];
        $this->flush_widget_cache();

        $alloptions = wp_cache_get( 'alloptions', 'options' );
        if ( isset($alloptions['widget_recent_entries']) )
            delete_option('widget_recent_entries');

        return $instance;
    }

    function flush_widget_cache() {
        wp_cache_delete('widget_recent_posts', 'widget');
    }

    function form( $instance ) {
        $title     = isset( $instance['title'] ) ? $instance['title'] : '';
        $number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
        $show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;
?>
        <p><label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>"><?php esc_html_e( 'Title:', 'vantage-bb' ); ?></label>
        <input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title); ?>" /></p>

        <p><label for="<?php echo esc_attr($this->get_field_id( 'number' )); ?>"><?php esc_html_e( 'Number of posts to show:', 'vantage-bb' ); ?></label>
        <input id="<?php echo esc_attr($this->get_field_id( 'number' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'number' )); ?>" type="text" value="<?php echo esc_attr($number); ?>" size="3" /></p>

        <p><input class="checkbox" type="checkbox" <?php checked( $show_date ); ?> id="<?php echo esc_attr($this->get_field_id( 'show_date' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'show_date' )); ?>" />
        <label for="<?php echo esc_attr($this->get_field_id( 'show_date' )); ?>"><?php esc_html_e( 'Display post date?', 'vantage-bb' ); ?></label></p>
<?php
    }
}

// Register and load the widget
function vn_load_widget() {
  register_widget( 'VN_Popular_Posts' );
  register_widget( 'VN_About_Author_Widget' );
  register_widget( 'VN_MG_Widget_Recent_Posts' );
}
add_action( 'widgets_init', 'vn_load_widget' );