<?php
/**
 * Contains methods for customizing the theme customization screen.
 *
 * @link http://codex.wordpress.org/Theme_Customization_API
 * @since Vantage 1.0
 */
class Vantage_Customize {
  public static function register( $wp_customize ) {

    /**
      * Modes Panel
      */
    $wp_customize->add_panel( 'vn_mode_panel', array(
      'priority' => 1,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Modes', 'vantage-bb' ),
    ) );

    // Modes Section
    $wp_customize->add_section( 'vn_mode_section', array(
      'priority' => 1,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Choose Mode', 'vantage-bb' ),
      'description' => '<a target="_blank" href="http://boldblocks.com/support/modes/">Learn more about Modes</a>',
      'panel' => 'vn_mode_panel',
    ) );

    // Modes
    $wp_customize->add_setting( 'vn_mode', array(
      'default' => 'multipurpose',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_mode', array(
      'type' => 'radio',
      'section' => 'vn_mode_section',
      'choices' => array(
        'multipurpose' => 'Multipurpose Mode',
        'magazine' => 'Magazine Mode',
        'blogger' => 'Blogger Mode',
        'photographer' => 'Photographer Mode'
      ),
    ) );

    // Magazine Mode Options Section
    $wp_customize->add_section( 'vn_magazine_section', array(
      'priority' => 30,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Magazine Mode Options', 'vantage-bb' ),
      'description' => esc_html__( '<i>Pro Tip: Make sure you <a href="<?php echo admin_url(); ?>admin.php?page=import" target="_blank">import the demo data</a> as it is required.</', 'vantage-bb' ),
      'panel' => 'vn_mode_panel',
      'active_callback' => 'vn_in_magazine_mode',
    ) );
    
    $wp_customize->add_setting( 'vn_mg_color_scheme', array(
      'default' => 'supermenumd__nobackground',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transform' => 'refresh',
      'sanitize_callback' => 'esc_attr',
      
    ) );
    $wp_customize->add_control( 'vn_mg_color_scheme', array(
      'label' => esc_html__( 'Topmenu Color Scheme', 'vantage-bb' ),
      'type' => 'radio',
      'section' => 'vn_magazine_section',
      'setting' => 'vn_mg_color_scheme',
      'choices' => array(
        'supermenumd__nobackground' => 'Your Customized Styling',
        'supermenumd__indigo' => 'Indigo',
        'supermenumd__red' => 'Red',
        'supermenumd__pink' => 'Pink',
        'supermenumd__purple' => 'Purple',
        'supermenumd__deeppurple' => 'Deep Purple',
        'supermenumd__blue' => 'Blue',
        'supermenumd__lightblue' => 'Light Blue',
        'supermenumd__cyan' => 'Cyan',
        'supermenumd__green' => 'Green',
        'supermenumd__lightgreen' => 'Light Green',
        'supermenumd__yellow' => 'Yellow',
        'supermenumd__amber' => 'Amber',
        'supermenumd__deeporange' => 'Deep Orange',
        'supermenumd__brown' => 'Brown',
        'supermenumd__bluegrey' => 'Blue Grey',
        'supermenumd__black' => 'Black',
      ),
    ) );
    
    // Show Border Bottom
    $wp_customize->add_setting( 'vn_mg_border_btm', array(
      'default' => 'no',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transform' => 'refresh',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_mg_border_btm', array(
      'label' => esc_html__( 'Show Border Bottom under Menu Items', 'vantage-bb' ),
      'type' => 'radio',
      'section' => 'vn_magazine_section',
      'setting' => 'sm_md_border_btm',
      'choices' => array(
        'yes' => 'Yes',
        'no' => 'No',
      ),
    ) );

    // Photographer Mode Options Section
    $wp_customize->add_section( 'vn_photographer_section', array(
      'priority' => 30,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Photographer Mode Options', 'vantage-bb' ),
      'description' => '',
      'panel' => 'vn_mode_panel',
      'active_callback' => 'vn_in_photographer_mode',
    ) );

    // PH: Post Type to Show
    $wp_customize->add_setting( 'vn_ph_post_type', array(
      'default' => 'post',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_ph_post_type', array(
      'label' => 'Posts type to show',
      'description' => esc_html__('', 'vantage-bb'),
      'type' => 'select',
      'settings' => 'vn_ph_post_type',
      'section' => 'vn_photographer_section',
      'choices' => array(
        'post' => 'Blog Posts',
        'dslc_galleries' => 'Galleries',
      ),
    ) );
    
    // PH: Slider Effect
    $wp_customize->add_setting( 'vn_ph_slider_effect', array(
      'default' => 'vn_slider_effect_1',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_ph_slider_effect', array(
      'label' => 'Slider Effect',
      'description' => esc_html__('', 'vantage-bb'),
      'type' => 'select',
      'settings' => 'vn_ph_slider_effect',
      'section' => 'vn_photographer_section',
      'choices' => array(
        'vn_slider_effect_1' => 'Slide',
        'vn_slider_effect_2' => 'Fade In',
      ),
    ) );
    
    // PH: Enable Mouse Move Animations
    $wp_customize->add_setting( 'vn_ph_mouse_animation', array(
      'default' => 'yes',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_ph_mouse_animation', array(
      'label' => 'Enable Mouse Move Animations',
      'description' => esc_html__('', 'vantage-bb'),
      'type' => 'select',
      'settings' => 'vn_ph_mouse_animation',
      'section' => 'vn_photographer_section',
      'choices' => array(
        'yes' => 'Yes',
        'no' => 'No',
      ),
    ) );
    
    // PH: Side Overlays
    $wp_customize->add_setting( 'vn_ph_maybe_overlays', array(
      'default' => 'yes',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_ph_maybe_overlays', array(
      'label' => 'Enable Side Overlays',
      'description' => esc_html__('', 'vantage-bb'),
      'type' => 'select',
      'settings' => 'vn_ph_maybe_overlays',
      'section' => 'vn_photographer_section',
      'choices' => array(
        'yes' => 'Yes',
        'no' => 'No',
      ),
    ) );

    // PH: Enable Cursor Follower
    $wp_customize->add_setting( 'vn_ph_cursor_follower', array(
      'default' => 'yes',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_ph_cursor_follower', array(
      'label' => 'Enable Cursor Follower',
      'description' => esc_html__('', 'vantage-bb'),
      'type' => 'select',
      'settings' => 'vn_ph_cursor_follower',
      'section' => 'vn_photographer_section',
      'choices' => array(
        'yes' => 'Yes',
        'no' => 'No',
      ),
    ) );

    /**
      * Global Panel
      */
    $wp_customize->add_panel( 'vn_global_panel', array(
      'priority' => 3,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Global', 'vantage-bb' ),
    ) );

    // Site Configs Section
    $wp_customize->add_section( 'vn_config_section', array(
      'priority' => 2,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Site Configs', 'vantage-bb' ),
      'description' => '',
      'panel' => 'vn_global_panel',
    ) );

    // Width
    $wp_customize->add_setting( 'vn_width', array(
      'default' => '1170',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_width', array(
      'label' => esc_html__( 'Width', 'vantage-bb' ),
      'section' => 'vn_config_section',
      'setting' => 'vn_width',
      'input_attrs' => array(
        'min'  => 768,
        'max'  => 1400,
        'step' => 1,
      ),
    ) ) );

    // Smooth Scroll
    $wp_customize->add_setting( 'vn_smoothscroll', array(
      'default' => 'disabled',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_smoothscroll', array(
      'label' => esc_html__( 'Smoothscroll', 'vantage-bb' ),
      'type' => 'radio',
      'section' => 'vn_config_section',
      'choices' => array(
        'enabled' => 'Enabled',
        'disabled' => 'Disabled',
      ),
    ) );

    // Selection Background Color
    $wp_customize->add_setting( 'vn_selection_color', array(
      'default' => 'rgba(0,0,0,0.4)',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Color_Alpha_Control( $wp_customize, 'vn_selection_color', array(
      'label' => 'Selection Background',
      'palette' => true,
      'section' => 'vn_config_section',
    ) ) );

    // Preloaders Section
    $wp_customize->add_section( 'vn_preloader_section', array(
      'priority' => 4,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Preloader', 'vantage-bb' ),
      'description' => '',
      'panel' => 'vn_global_panel'
    ) );

    // Progress Bar
    $wp_customize->add_setting( 'vn_progress_bar', array(
      'default' => 'yes',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_progress_bar', array(
      'label' => esc_html__( 'Show Progress Bar on top?', 'vantage-bb' ),
      'type' => 'radio',
      'section' => 'vn_preloader_section',
      'choices' => array(
        'yes' => 'Yes',
        'no' => 'No',
      ),
    ) );

    // Progress Bar Color
    $wp_customize->add_setting( 'vn_progress_bar_color', array(
      'default' => '#9ecc4b',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Color_Alpha_Control( $wp_customize, 'vn_progress_bar_color', array(
      'label' => esc_html__( 'Progress Bar Color', 'vantage-bb' ),
      'settings' => 'vn_progress_bar_color',
      'section' => 'vn_preloader_section',
    ) ) );


    // Page Transitions
    $wp_customize->add_setting( 'vn_page_transitions', array(
      'default' => 'yes',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_page_transitions', array(
      'label' => esc_html__( 'Enable Page Transitions?', 'vantage-bb' ),
      'type' => 'radio',
      'setting' => 'vn_page_transitions',
      'section' => 'vn_preloader_section',
      'choices' => array(
        'yes' => 'Yes',
        'no' => 'No',
      ),
    ) );
    
    // Widget Background
    $wp_customize->add_setting( 'vn_page_transitions_bg', array(
      'default' => '#ffffff',
      'sanitize_callback' => 'esc_attr',
      
    ) );
    $wp_customize->add_control( new VN_Color_Alpha_Control( $wp_customize, 'vn_page_transitions_bg', array(
      'label' => 'Page Transitions Background',
      'settings' => 'vn_page_transitions_bg',
      'priority' => 60,
      'section' => 'vn_preloader_section',
    ) ) );
    
    // Page Transitions
    $wp_customize->add_setting( 'vn_pg_trns_show_logo', array(
      'default' => 'yes',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_pg_trns_show_logo', array(
      'label' => esc_html__( 'Show Logo on Preloading Screen?', 'vantage-bb' ),
      'type' => 'radio',
      'setting' => 'vn_pg_trns_show_logo',
      'section' => 'vn_preloader_section',
      'choices' => array(
        'yes' => 'Yes',
        'no' => 'No',
      ),
    ) );
    
    // Topmenu Image Logo
    $wp_customize->add_setting( 'vn_pg_trns_logo', array(
      'default' => VANTAGE_TEMPLATE_URI.'/assets/img/logo/vantage-icon-black.png',
      'sanitize_callback' => 'esc_url',
    ) );
    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'vn_pg_trns_logo', array(
      'label' => esc_html__( 'Image to be displayed on Preloading Screen', 'vantage-bb' ),
      'section' => 'vn_preloader_section',
      'setting' => 'vn_pg_trns_logo',
    ) ) );

    
    // Back to Top Section
    $wp_customize->add_section( 'vn_btt_section', array(
      'priority' => 5,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Back to Top', 'vantage-bb' ),
      'description' => '',
      'panel' => 'vn_global_panel',
    ) );
    
    // Back to Top Style
    $wp_customize->add_setting( 'vn_btt_style', array(
      'default' => 'vn__btt--arrow-rounded',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_btt_style', array(
      'label' => esc_html__( 'Back to Top Style', 'vantage-bb' ),
      'type' => 'select',
      'setting' => 'vn_btt_style',
      'section' => 'vn_btt_section',
      'choices' => array(
        'vn__btt--arrow-rounded' => 'Arrow Round',
        'vn__btt--arrow-squared' => 'Arrow Squared',
        'vn__btt--text' => 'Back to Top Text',
      ),
    ) );
    
    // Back to Top Background Color
    $wp_customize->add_setting( 'vn_btt_background', array(
      'default' => '#9ecc4b',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Color_Alpha_Control( $wp_customize, 'vn_btt_background', array(
      'label' => esc_html__( 'Back to Top Arrow Background', 'vantage-bb' ),
      'settings' => 'vn_btt_background',
      'section' => 'vn_btt_section',
    ) ) );
    
    // Page Title Padding
    $wp_customize->add_setting( 'vn_btt_visibility', array(
      'default' => '800',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_btt_visibility', array(
      'label' => esc_html__( 'Show back to top after', 'vantage-bb' ),
      'description' => esc_html__( 'The scrolling distance from top after which Back to Top button will be visible', 'vantage-bb' ),
      'section' => 'vn_btt_section',
      'setting' => 'vn_btt_visibility',
      'input_attrs' => array(
        'min'  => 100,
        'max'  => 20000,
        'step' => 100,
      ),
    ) ) );

    // Show Back to Top of Single
    $wp_customize->add_setting( 'vn_btt_single', array(
      'default' => 1,
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_btt_single', array(
      'label' => esc_html__( 'Show Back to Top Button on Posts', 'vantage-bb' ),
      'type' => 'checkbox',
      'section' => 'vn_btt_section',
    ) );
    
    // Show Back to Top on Archive
    $wp_customize->add_setting( 'vn_btt_archive', array(
      'default' => 1,
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_btt_archive', array(
      'label' => esc_html__( 'Show Back to Top Button on Archive', 'vantage-bb' ),
      'type' => 'checkbox',
      'section' => 'vn_btt_section',
    ) );
    
    // Show Back to Top on Home
    $wp_customize->add_setting( 'vn_btt_home', array(
      'default' => 1,
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_btt_home', array(
      'label' => esc_html__( 'Show Back to Top Button on Home', 'vantage-bb' ),
      'type' => 'checkbox',
      'section' => 'vn_btt_section',
    ) );
    
    // Show Back to Top of Page
    $wp_customize->add_setting( 'vn_btt_page', array(
      'default' => 0,
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_btt_page', array(
      'label' => esc_html__( 'Show Back to Top Button on Page', 'vantage-bb' ),
      'type' => 'checkbox',
      'section' => 'vn_btt_section',
      'choices' => array(
        'yes' => 'Show',
        'no' => 'Hide',
      ),
    ) );
    

    $wp_customize->get_section( 'title_tagline' )->panel = 'vn_global_panel';
    $wp_customize->get_section( 'colors' )->panel = 'vn_global_panel';
    $wp_customize->get_section( 'background_image' )->panel = 'vn_global_panel';
    if (class_exists('sm_bootstrap_navwalker')) {
      $wp_customize->get_section( 'nav' )->panel = 'sm_supermenu_panel';
    }
    if ($wp_customize->get_section('static_front_page')) {
      $wp_customize->get_section( 'static_front_page' )->panel = 'vn_global_panel';
    }

    /**
      * Typography Panel
      */
    $wp_customize->add_panel( 'vn_typography_panel', array(
      'priority' => 5,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Typography', 'vantage-bb' ),
    ) );

    

    $vn_font_choices = vn_customizer_library_get_font_choices();

    // p Color
    $wp_customize->add_setting( 'vn_p_color', array(
      'default' => '#666666',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'vn_p_color', array(
      'label' => 'Color',
      'section' => 'vn_p_type_section',
      'setting' => 'vn_p_color'
    ) ) );

    // Body/Paragraph Typography
    $wp_customize->add_section( 'vn_p_type_section', array(
      'priority' => 4,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Body/Paragraph Typography', 'vantage-bb' ),
      'description' => '',
      'panel' => 'vn_typography_panel',
    ) );

    // Body Font Family
    $wp_customize->add_setting( 'vn_p_font_family', array(
      'default' => 'Lora',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_p_font_family', array(
      'label' => esc_html__( 'Font Family', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_p_type_section',
      'choices' => $vn_font_choices,
    ) );

    // p Font Size
    $wp_customize->add_setting( 'vn_p_font_size', array(
      'default' => '14',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_p_font_size', array(
      'label' => esc_html__( 'Font Size', 'vantage-bb' ),
      'section' => 'vn_p_type_section',
      'setting' => 'vn_p_font_size',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 120,
        'step' => 1,
      ),
    ) ) );

    // p Font Weight
    $wp_customize->add_setting( 'vn_p_font_weight', array(
      'default' => '500',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_p_font_weight', array(
      'label' => esc_html__( 'Font Weight', 'vantage-bb' ),
      'section' => 'vn_p_type_section',
      'setting' => 'vn_p_font_weight',
      'input_attrs' => array(
        'min'  => 100,
        'max'  => 900,
        'step' => 100,
      ),
    ) ) );

    // p Letter Spacing
    $wp_customize->add_setting( 'vn_p_letter_spacing', array(
      'default' => '0',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_p_letter_spacing', array(
      'label' => esc_html__( 'Letter Spacing', 'vantage-bb' ),
      'section' => 'vn_p_type_section',
      'setting' => 'vn_p_letter_spacing',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 30,
        'step' => 1,
      ),
    ) ) );

    // p Text Transform
    $wp_customize->add_setting( 'vn_p_text_transform', array(
      'default' => 'none',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transform' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_p_text_transform', array(
      'label' => esc_html__( 'Text Transform', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_p_type_section',
      'setting' => 'vn_p_text_transform',
      'choices' => array(
        'none'  => 'None',
        'capitalize' => 'Capitalize',
        'uppercase' => 'Uppercase',
        'lowercase' => 'Lowercase',
        'initial' => 'Initial',
        'inherit' => 'Inherit'
      ),
    ) );




    // H1 Typography
    $wp_customize->add_section( 'vn_h1_type_section', array(
      'priority' => 5,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'H1 Typography', 'vantage-bb' ),
      'description' => esc_html__('This won\'t affect the modules added by Drag & Drop.', 'vantage-bb'),
      'panel' => 'vn_typography_panel',
    ) );

    // H1 Color
    $wp_customize->add_setting( 'vn_h1_color', array(
      'default' => '#333333',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'vn_h1_color', array(
      'label' => 'Color',
      'section' => 'vn_h1_type_section',
      'setting' => 'vn_h1_color'
    ) ) );

    // H1 Font Family
    $wp_customize->add_setting( 'vn_h1_font_family', array(
      'default' => 'Raleway',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_h1_font_family', array(
      'label' => esc_html__( 'Font Family', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_h1_type_section',
      'choices' => $vn_font_choices,
    ) );

    // H1 Font Size
    $wp_customize->add_setting( 'vn_h1_font_size', array(
      'default' => '36',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h1_font_size', array(
      'label' => esc_html__( 'Font Size', 'vantage-bb' ),
      'section' => 'vn_h1_type_section',
      'setting' => 'vn_h1_font_size',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 120,
        'step' => 1,
      ),
    ) ) );

    // H1 Font Weight
    $wp_customize->add_setting( 'vn_h1_font_weight', array(
      'default' => '500',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h1_font_weight', array(
      'label' => esc_html__( 'Font Weight', 'vantage-bb' ),
      'section' => 'vn_h1_type_section',
      'setting' => 'vn_h1_font_weight',
      'input_attrs' => array(
        'min'  => 100,
        'max'  => 900,
        'step' => 100,
      ),
    ) ) );

    // H1 Letter Spacing
    $wp_customize->add_setting( 'vn_h1_letter_spacing', array(
      'default' => '0',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h1_letter_spacing', array(
      'label' => esc_html__( 'Letter Spacing', 'vantage-bb' ),
      'section' => 'vn_h1_type_section',
      'setting' => 'vn_h1_letter_spacing',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 30,
        'step' => 1,
      ),
    ) ) );

    // H1 Text Transform
    $wp_customize->add_setting( 'vn_h1_text_transform', array(
      'default' => 'none',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transform' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_h1_text_transform', array(
      'label' => esc_html__( 'Text Transform', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_h1_type_section',
      'setting' => 'vn_h1_text_transform',
      'choices' => array(
        'none'  => 'None',
        'capitalize' => 'Capitalize',
        'uppercase' => 'Uppercase',
        'lowercase' => 'Lowercase',
        'initial' => 'Initial',
        'inherit' => 'Inherit'
      ),
    ) );




    // H2 Typography
    $wp_customize->add_section( 'vn_h2_type_section', array(
      'priority' => 6,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'H2 Typography', 'vantage-bb' ),
      'description' => esc_html__('This won\'t affect the modules added by Drag & Drop.', 'vantage-bb'),
      'panel' => 'vn_typography_panel',
    ) );

    // h2 Color
    $wp_customize->add_setting( 'vn_h2_color', array(
      'default' => '#333333',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'vn_h2_color', array(
      'label' => 'Color',
      'section' => 'vn_h2_type_section',
      'setting' => 'vn_h2_color'
    ) ) );

    // h2 Font Family
    $wp_customize->add_setting( 'vn_h2_font_family', array(
      'default' => 'Raleway',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_h2_font_family', array(
      'label' => esc_html__( 'Font Family', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_h2_type_section',
      'choices' => $vn_font_choices,
    ) );

    // h2 Font Size
    $wp_customize->add_setting( 'vn_h2_font_size', array(
      'default' => '30',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h2_font_size', array(
      'label' => esc_html__( 'Font Size', 'vantage-bb' ),
      'section' => 'vn_h2_type_section',
      'setting' => 'vn_h2_font_size',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 120,
        'step' => 1,
      ),
    ) ) );

    // h2 Font Weight
    $wp_customize->add_setting( 'vn_h2_font_weight', array(
      'default' => '500',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h2_font_weight', array(
      'label' => esc_html__( 'Font Weight', 'vantage-bb' ),
      'section' => 'vn_h2_type_section',
      'setting' => 'vn_h2_font_weight',
      'input_attrs' => array(
        'min'  => 100,
        'max'  => 900,
        'step' => 100,
      ),
    ) ) );

    // h2 Letter Spacing
    $wp_customize->add_setting( 'vn_h2_letter_spacing', array(
      'default' => '0',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h2_letter_spacing', array(
      'label' => esc_html__( 'Letter Spacing', 'vantage-bb' ),
      'section' => 'vn_h2_type_section',
      'setting' => 'vn_h2_letter_spacing',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 30,
        'step' => 1,
      ),
    ) ) );

    // h2 Text Transform
    $wp_customize->add_setting( 'vn_h2_text_transform', array(
      'default' => 'none',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transform' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_h2_text_transform', array(
      'label' => esc_html__( 'Text Transform', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_h2_type_section',
      'setting' => 'vn_h2_text_transform',
      'choices' => array(
        'none'  => 'None',
        'capitalize' => 'Capitalize',
        'uppercase' => 'Uppercase',
        'lowercase' => 'Lowercase',
        'initial' => 'Initial',
        'inherit' => 'Inherit'
      ),
    ) );




    // h3 Typography
    $wp_customize->add_section( 'vn_h3_type_section', array(
      'priority' => 7,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'H3 Typography', 'vantage-bb' ),
      'description' => esc_html__('This won\'t affect the modules added by Drag & Drop.', 'vantage-bb'),
      'panel' => 'vn_typography_panel',
    ) );

    // h3 Color
    $wp_customize->add_setting( 'vn_h3_color', array(
      'default' => '#333333',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'vn_h3_color', array(
      'label' => 'Color',
      'section' => 'vn_h3_type_section',
      'setting' => 'vn_h3_color'
    ) ) );

    // h3 Font Family
    $wp_customize->add_setting( 'vn_h3_font_family', array(
      'default' => 'Raleway',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_h3_font_family', array(
      'label' => esc_html__( 'Font Family', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_h3_type_section',
      'choices' => $vn_font_choices,
    ) );

    // h3 Font Size
    $wp_customize->add_setting( 'vn_h3_font_size', array(
      'default' => '24',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h3_font_size', array(
      'label' => esc_html__( 'Font Size', 'vantage-bb' ),
      'section' => 'vn_h3_type_section',
      'setting' => 'vn_h3_font_size',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 120,
        'step' => 1,
      ),
    ) ) );

    // h3 Font Weight
    $wp_customize->add_setting( 'vn_h3_font_weight', array(
      'default' => '500',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h3_font_weight', array(
      'label' => esc_html__( 'Font Weight', 'vantage-bb' ),
      'section' => 'vn_h3_type_section',
      'setting' => 'vn_h3_font_weight',
      'input_attrs' => array(
        'min'  => 100,
        'max'  => 900,
        'step' => 100,
      ),
    ) ) );

    // h3 Letter Spacing
    $wp_customize->add_setting( 'vn_h3_letter_spacing', array(
      'default' => '0',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h3_letter_spacing', array(
      'label' => esc_html__( 'Letter Spacing', 'vantage-bb' ),
      'section' => 'vn_h3_type_section',
      'setting' => 'vn_h3_letter_spacing',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 30,
        'step' => 1,
      ),
    ) ) );

    // h3 Text Transform
    $wp_customize->add_setting( 'vn_h3_text_transform', array(
      'default' => 'none',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transform' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_h3_text_transform', array(
      'label' => esc_html__( 'Text Transform', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_h3_type_section',
      'setting' => 'vn_h3_text_transform',
      'choices' => array(
        'none'  => 'None',
        'capitalize' => 'Capitalize',
        'uppercase' => 'Uppercase',
        'lowercase' => 'Lowercase',
        'initial' => 'Initial',
        'inherit' => 'Inherit'
      ),
    ) );




    // h4 Typography
    $wp_customize->add_section( 'vn_h4_type_section', array(
      'priority' => 8,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'H4 Typography', 'vantage-bb' ),
      'description' => esc_html__('This won\'t affect the modules added by Drag & Drop.', 'vantage-bb'),
      'panel' => 'vn_typography_panel',
    ) );

    // h4 Color
    $wp_customize->add_setting( 'vn_h4_color', array(
      'default' => '#333333',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'vn_h4_color', array(
      'label' => 'Color',
      'section' => 'vn_h4_type_section',
      'setting' => 'vn_h4_color'
    ) ) );

    // h4 Font Family
    $wp_customize->add_setting( 'vn_h4_font_family', array(
      'default' => 'Raleway',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_h4_font_family', array(
      'label' => esc_html__( 'Font Family', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_h4_type_section',
      'choices' => $vn_font_choices,
    ) );

    // h4 Font Size
    $wp_customize->add_setting( 'vn_h4_font_size', array(
      'default' => '18',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h4_font_size', array(
      'label' => esc_html__( 'Font Size', 'vantage-bb' ),
      'section' => 'vn_h4_type_section',
      'setting' => 'vn_h4_font_size',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 120,
        'step' => 1,
      ),
    ) ) );

    // h4 Font Weight
    $wp_customize->add_setting( 'vn_h4_font_weight', array(
      'default' => '500',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h4_font_weight', array(
      'label' => esc_html__( 'Font Weight', 'vantage-bb' ),
      'section' => 'vn_h4_type_section',
      'setting' => 'vn_h4_font_weight',
      'input_attrs' => array(
        'min'  => 100,
        'max'  => 900,
        'step' => 100,
      ),
    ) ) );

    // h4 Letter Spacing
    $wp_customize->add_setting( 'vn_h4_letter_spacing', array(
      'default' => '0',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h4_letter_spacing', array(
      'label' => esc_html__( 'Letter Spacing', 'vantage-bb' ),
      'section' => 'vn_h4_type_section',
      'setting' => 'vn_h4_letter_spacing',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 30,
        'step' => 1,
      ),
    ) ) );

    // h4 Text Transform
    $wp_customize->add_setting( 'vn_h4_text_transform', array(
      'default' => 'none',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transform' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_h4_text_transform', array(
      'label' => esc_html__( 'Text Transform', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_h4_type_section',
      'setting' => 'vn_h4_text_transform',
      'choices' => array(
        'none'  => 'None',
        'capitalize' => 'Capitalize',
        'uppercase' => 'Uppercase',
        'lowercase' => 'Lowercase',
        'initial' => 'Initial',
        'inherit' => 'Inherit'
      ),
    ) );






    // h5 Typography
    $wp_customize->add_section( 'vn_h5_type_section', array(
      'priority' => 9,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'H5 Typography', 'vantage-bb' ),
      'description' => esc_html__('This won\'t affect the modules added by Drag & Drop.', 'vantage-bb'),
      'panel' => 'vn_typography_panel',
    ) );

    // h5 Color
    $wp_customize->add_setting( 'vn_h5_color', array(
      'default' => '#333333',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'vn_h5_color', array(
      'label' => 'Color',
      'section' => 'vn_h5_type_section',
      'setting' => 'vn_h5_color'
    ) ) );

    // h5 Font Family
    $wp_customize->add_setting( 'vn_h5_font_family', array(
      'default' => 'Raleway',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_h5_font_family', array(
      'label' => esc_html__( 'Font Family', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_h5_type_section',
      'choices' => $vn_font_choices,
    ) );

    // h5 Font Size
    $wp_customize->add_setting( 'vn_h5_font_size', array(
      'default' => '14',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h5_font_size', array(
      'label' => esc_html__( 'Font Size', 'vantage-bb' ),
      'section' => 'vn_h5_type_section',
      'setting' => 'vn_h5_font_size',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 120,
        'step' => 1,
      ),
    ) ) );

    // h5 Font Weight
    $wp_customize->add_setting( 'vn_h5_font_weight', array(
      'default' => '500',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h5_font_weight', array(
      'label' => esc_html__( 'Font Weight', 'vantage-bb' ),
      'section' => 'vn_h5_type_section',
      'setting' => 'vn_h5_font_weight',
      'input_attrs' => array(
        'min'  => 100,
        'max'  => 900,
        'step' => 100,
      ),
    ) ) );

    // h5 Letter Spacing
    $wp_customize->add_setting( 'vn_h5_letter_spacing', array(
      'default' => '0',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h5_letter_spacing', array(
      'label' => esc_html__( 'Letter Spacing', 'vantage-bb' ),
      'section' => 'vn_h5_type_section',
      'setting' => 'vn_h5_letter_spacing',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 30,
        'step' => 1,
      ),
    ) ) );

    // h5 Text Transform
    $wp_customize->add_setting( 'vn_h5_text_transform', array(
      'default' => 'none',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transform' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_h5_text_transform', array(
      'label' => esc_html__( 'Text Transform', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_h5_type_section',
      'setting' => 'vn_h5_text_transform',
      'choices' => array(
        'none'  => 'None',
        'capitalize' => 'Capitalize',
        'uppercase' => 'Uppercase',
        'lowercase' => 'Lowercase',
        'initial' => 'Initial',
        'inherit' => 'Inherit'
      ),
    ) );





    // h6 Typography
    $wp_customize->add_section( 'vn_h6_type_section', array(
      'priority' => 10,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'H6 Typography', 'vantage-bb' ),
      'description' => esc_html__('This won\'t affect the modules added by Drag & Drop.', 'vantage-bb'),
      'panel' => 'vn_typography_panel',
    ) );

    // h6 Color
    $wp_customize->add_setting( 'vn_h6_color', array(
      'default' => '#333333',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'vn_h6_color', array(
      'label' => 'Color',
      'section' => 'vn_h6_type_section',
      'setting' => 'vn_h6_color'
    ) ) );

    // h6 Font Family
    $wp_customize->add_setting( 'vn_h6_font_family', array(
      'default' => 'Lato',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_h6_font_family', array(
      'label' => esc_html__( 'Font Family', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_h6_type_section',
      'choices' => $vn_font_choices,
    ) );

    // h6 Font Size
    $wp_customize->add_setting( 'vn_h6_font_size', array(
      'default' => '12',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h6_font_size', array(
      'label' => esc_html__( 'Font Size', 'vantage-bb' ),
      'section' => 'vn_h6_type_section',
      'setting' => 'vn_h6_font_size',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 120,
        'step' => 1,
      ),
    ) ) );

    // h6 Font Weight
    $wp_customize->add_setting( 'vn_h6_font_weight', array(
      'default' => '500',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h6_font_weight', array(
      'label' => esc_html__( 'Font Weight', 'vantage-bb' ),
      'section' => 'vn_h6_type_section',
      'setting' => 'vn_h6_font_weight',
      'input_attrs' => array(
        'min'  => 100,
        'max'  => 900,
        'step' => 100,
      ),
    ) ) );

    // h6 Letter Spacing
    $wp_customize->add_setting( 'vn_h6_letter_spacing', array(
      'default' => '0',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_h6_letter_spacing', array(
      'label' => esc_html__( 'Letter Spacing', 'vantage-bb' ),
      'section' => 'vn_h6_type_section',
      'setting' => 'vn_h6_letter_spacing',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 30,
        'step' => 1,
      ),
    ) ) );

    // h6 Text Transform
    $wp_customize->add_setting( 'vn_h6_text_transform', array(
      'default' => 'none',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transform' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_h6_text_transform', array(
      'label' => esc_html__( 'Text Transform', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_h6_type_section',
      'setting' => 'vn_h6_text_transform',
      'choices' => array(
        'none'  => 'None',
        'capitalize' => 'Capitalize',
        'uppercase' => 'Uppercase',
        'lowercase' => 'Lowercase',
        'initial' => 'Initial',
        'inherit' => 'Inherit'
      ),
    ) );

    /**
      * Button Panel
      */
    $wp_customize->add_panel( 'vn_button_panel', array(
      'priority' => 6,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Buttons & Link', 'vantage-bb' ),
    ) );
    
    // Link Color Section
    $wp_customize->add_section( 'vn_links_section', array(
      'priority' => 2,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Link Color', 'vantage-bb' ),
      'description' => '',
      'panel' => 'vn_button_panel',
    ) );

    // Link Color
    $wp_customize->add_setting( 'vn_links_color', array(
      'default' => '#333333',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'vn_links_color', array(
      'label' => 'Link Color',
      'section' => 'vn_links_section',
    ) ) );

    // Link Color - Hover
    $wp_customize->add_setting( 'vn_links_color_hover', array(
      'default' => '#9ecc4b',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'vn_links_color_hover', array(
      'label' => 'Link Color - Hover',
      'section' => 'vn_links_section',
    ) ) );
    
    // Button Section
    $wp_customize->add_section( 'vn_button_section', array(
      'priority' => 20,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Button Default Styling', 'vantage-bb' ),
      'description' => '',
      'panel' => 'vn_button_panel',
    ) );
    
    // Button Style
    $wp_customize->add_setting( 'vn_btn_style', array(
      'default' => 'solidshadowless',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_btn_style', array(
      'label' => esc_html__( 'Button Shadow', 'vantage-bb' ),
      'type' => 'radio',
      'section' => 'vn_button_section',
      'choices' => array(
        'solidshadowless' => 'Solid - Shadowless',
        'solidshadow' => 'Solid - Shadow',
        'bordershadowless' => 'Bordered - Shadowless',
        
      ),
    ) );
    
    //Default Button Background
    $wp_customize->add_setting( 'vn_btn_bg', array(
      'default' => '#9ecc4b',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Color_Alpha_Control( $wp_customize, 'vn_btn_bg', array(
      'label' => esc_html__( 'Button Background or Border', 'vantage-bb' ),
      'settings' => 'vn_btn_bg',
      'section' => 'vn_button_section',
    ) ) );
    
    //Default Button Background
    $wp_customize->add_setting( 'vn_btn_bg_hover', array(
      'default' => '#232323',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Color_Alpha_Control( $wp_customize, 'vn_btn_bg_hover', array(
      'label' => esc_html__( 'Button Background - Hover or Border Hover', 'vantage-bb' ),
      'settings' => 'vn_btn_bg_hover',
      'section' => 'vn_button_section',
    ) ) );
    
    // Button Color
    $wp_customize->add_setting( 'vn_btn_color', array(
      'default' => '#ffffff',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'vn_btn_color', array(
      'label' => 'Color',
      'section' => 'vn_button_section',
      'setting' => 'vn_btn_color'
    ) ) );
    
    // Button Color Hover
    $wp_customize->add_setting( 'vn_btn_color_hover', array(
      'default' => '#ffffff',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'vn_btn_color_hover', array(
      'label' => 'Color - Hover',
      'section' => 'vn_button_section',
      'setting' => 'vn_btn_color_hover'
    ) ) );
    
    // Button Font Weight
    $wp_customize->add_setting( 'vn_btn_font_weight', array(
      'default' => '600',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_btn_font_weight', array(
      'label' => esc_html__( 'Button Font Weight', 'vantage-bb' ),
      'section' => 'vn_button_section',
      'setting' => 'vn_btn_font_weight',
      'input_attrs' => array(
        'min'  => 100,
        'max'  => 900,
        'step' => 100,
      ),
    ) ) );
    
    // Button Font Family
    $wp_customize->add_setting( 'vn_btn_font_family', array(
      'default' => 'Montserrat',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_btn_font_family', array(
      'label' => esc_html__( 'Button Font Family', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_button_section',
      'choices' => $vn_font_choices,
    ) );
    
    // Widget Border Width
    $wp_customize->add_setting( 'vn_btn_border_rad', array(
      'default' => '3',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_btn_border_rad', array(
      'label' => esc_html__( 'Button Border Radius', 'vantage-bb' ),
      'section' => 'vn_button_section',
      'setting' => 'vn_btn_border_rad',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 30,
        'step' => 1,
      ),
    ) ) );
    
    // Button Hover Effect
    $wp_customize->add_setting( 'vn_btn_hover_eff', array(
      'default' => 'none',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_btn_hover_eff', array(
      'label' => esc_html__( 'Button Hover Effect', 'vantage-bb' ),
      'type' => 'select',
      'section' => 'vn_button_section',
      'choices' => array(
        'none' => 'None',
        'opacity' => 'Opacity',
        'riseup' => 'Rise Up',
      ),
    ) );
    
    
    
  

    /**
      * Sidebar Panel
      */
    $wp_customize->add_panel( 'vn_sidebar_panel', array(
      'priority' => 9,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Sidebar', 'vantage-bb' ),
    ) );
    // Sidebar Section
    $wp_customize->add_section( 'vn_sidebar_section', array(
      'priority' => 80,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Sidebar', 'vantage-bb' ),
      'description' => '',
      'panel' => 'vn_sidebar_panel',
    ) );

    // Widget Background
    $wp_customize->add_setting( 'vn_widget_bg', array(
      'default' => '#ffffff',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Color_Alpha_Control( $wp_customize, 'vn_widget_bg', array(
      'label' => 'Widget Background',
      'settings' => 'vn_widget_bg',
      'section' => 'vn_sidebar_section',
    ) ) );


    // Widget Border Width
    $wp_customize->add_setting( 'vn_widget_border_width', array(
      'default' => '1',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'transport' => 'postMessage',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( new VN_Customize_Range_Control( $wp_customize, 'vn_widget_border_width', array(
      'label' => esc_html__( 'Widget Border Width', 'vantage-bb' ),
      'section' => 'vn_sidebar_section',
      'setting' => 'vn_widget_border_width',
      'input_attrs' => array(
        'min'  => 0,
        'max'  => 10,
        'step' => 1,
      ),
    ) ) );

    // Widget Border Color
    $wp_customize->add_setting( 'vn_widget_border_color', array(
      'default' => '#f0f0f0',
      'sanitize_callback' => 'sanitize_hex_color',
      'transport' => 'postMessage',
    ) );
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'vn_widget_border_color', array(
      'label' => 'Widget Border Color',
      'section' => 'vn_sidebar_section',
    ) ) );

    // Widget Text Alignment
    $wp_customize->add_setting( 'vn_widget_alignment', array(
      'default' => 'left',
      'type' => 'theme_mod',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );

    function vn_sanitize_text( $input ) {
      return wp_kses_post( force_balance_tags( $input ) );
    }

    /**
      * Advanced Panel
      */
    $wp_customize->add_panel( 'vn_advanced_panel', array(
      'priority' => 120,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Advanced', 'vantage-bb' ),
    ) );
    // Advanced Section
    $wp_customize->add_section( 'vn_advanced_section', array(
      'priority' => 180,
      'capability' => 'edit_theme_options',
      'theme_supports' => '',
      'title' => esc_html__( 'Advanced', 'vantage-bb' ),
      'description' => '',
      'panel' => 'vn_advanced_panel',
    ) );

    // Custom CSS
    $wp_customize->add_setting( 'vn_custom_css', array(
      'default' => '',
      'sanitize_callback'    => 'wp_filter_nohtml_kses',
      'sanitize_js_callback' => 'wp_filter_nohtml_kses',
      'capability' => 'edit_themes', // We don't want all multisite users to be able to add Custom CSS
    ) );
    $wp_customize->add_control( new VN_Customize_Textarea_Control( $wp_customize, 'vn_custom_css', array(
      'label' => 'Custom CSS',
      'section' => 'vn_advanced_section',
      'setting' => 'vn_custom_css',
    ) ) );
    
    $wp_customize->add_setting( 'vn_production_env', array(
      'default' => 'no',
      'type' => 'theme_mod',
      'section' => 'vn_advanced_section',
      'capability' => 'edit_theme_options',
      'sanitize_callback' => 'esc_attr',
    ) );
    $wp_customize->add_control( 'vn_production_env', array(
      'label' => esc_html__( 'Production Environment', 'vantage-bb' ),
      'description' => esc_html__( 'Enable this if you\'re done with the development process and are ready to go live. This will minify all the CSS and JS (both files and Customizer Generated), will lock the Mode Changing Feature and other minor changes for better performance. <strong>Make sure you refresh the whole page after changing this option.</strong>', 'vantage-bb' ),
      'type' => 'radio',
      'section' => 'vn_advanced_section',
      'choices' => array(
        'yes' => 'Enable',
        'no' => 'Disable',
      ),
    ) );

    if (class_exists('CEI_Core')) {
      $wp_customize->get_section( 'cei-section' )->panel = 'vn_advanced_panel';
    }

  }

  // Generate Custom CSS
  public static function header_output() {
    if (vn_production_environment()) {
      require_once('styles.min.php');
    } else {
      require_once('styles.php');
    }
  }

  // Output Javascript
  public static function live_preview() {
    wp_enqueue_script( 'vn-customizer-preview', get_template_directory_uri() . '/assets/js/vn.customizer-preview.js', array(  'jquery', 'customize-preview' ), '', true );
  }
}


// Setup the Theme Customizer settings and controls
add_action( 'customize_register' , array( 'Vantage_Customize' , 'register' ) );

// Output custom CSS to live site
add_action( 'wp_head' , array( 'Vantage_Customize' , 'header_output' ) );

// Enqueue live preview javascript in Theme Customizer admin screen
add_action( 'customize_preview_init' , array( 'Vantage_Customize' , 'live_preview' ) );

// Custom theme scripts
function theme_customize_style() {
  wp_enqueue_script( 'vn-customizer-js', get_template_directory_uri() . '/assets/js/vn.customizer.js', array( 'jquery', 'customize-controls' ), '', true );
   wp_localize_script( 'vn-customizer-js', 'vantage_customizer_vars', array(
      'production_env'						=> (vn_production_environment() ? true : false),
      
    ) );
}
add_action( 'customize_controls_enqueue_scripts', 'theme_customize_style' );